@@ -1,20 +1,8 @@
 /*
- * Copyright © 2016 Red Hat, Inc
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-FileCopyrightText: 2016 Red Hat Inc
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2016 Jan Grulich <jgrulich@redhat.com>
  */
 
 #include "notification.h"
@@ -55,9 +43,7 @@ NotificationPortal::~NotificationPortal()
 {
 }
 
-void NotificationPortal::AddNotification(const QString &app_id,
-                                   const QString &id,
-                                   const QVariantMap &notification)
+void NotificationPortal::AddNotification(const QString &app_id, const QString &id, const QVariantMap &notification)
 {
     qCDebug(XdgDesktopPortalKdeNotification) << "AddNotification called with parameters:";
     qCDebug(XdgDesktopPortalKdeNotification) << "    app_id: " << app_id;
@@ -102,8 +88,7 @@ void NotificationPortal::AddNotification(const QString &app_id,
         notify->setUrgency(KNotification::CriticalUrgency);
     }
 
-    if (notification.contains(QStringLiteral("default-action"))
-            && notification.contains(QStringLiteral("default-action-target"))) {
+    if (notification.contains(QStringLiteral("default-action")) && notification.contains(QStringLiteral("default-action-target"))) {
         // default action is conveniently mapped to action number 0 so it uses the same action invocation method as the others
         notify->setDefaultAction(notification.value(QStringLiteral("default-action")).toString());
     }
@@ -138,7 +123,7 @@ void NotificationPortal::AddNotification(const QString &app_id,
 
 void NotificationPortal::notificationActivated(uint action)
 {
-    KNotification *notify = qobject_cast<KNotification*>(sender());
+    KNotification *notify = qobject_cast<KNotification *>(sender());
 
     if (!notify) {
         return;
@@ -159,8 +144,7 @@ void NotificationPortal::notificationActivated(uint action)
     QDBusConnection::sessionBus().send(message);
 }
 
-void NotificationPortal::RemoveNotification(const QString &app_id,
-                                      const QString &id)
+void NotificationPortal::RemoveNotification(const QString &app_id, const QString &id)
 {
     qCDebug(XdgDesktopPortalKdeNotification) << "RemoveNotification called with parameters:";
     qCDebug(XdgDesktopPortalKdeNotification) << "    app_id: " << app_id;
@@ -175,7 +159,7 @@ void NotificationPortal::RemoveNotification(const QString &app_id,
 
 void NotificationPortal::notificationClosed()
 {
-    KNotification *notify = qobject_cast<KNotification*>(sender());
+    KNotification *notify = qobject_cast<KNotification *>(sender());
 
     if (!notify) {
         return;
